"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const reporter_1 = require("@hayspec/reporter");
class DefaultReporter {
    constructor() {
        this.printer = new reporter_1.Printer();
    }
    onCompileStart(compiler) {
        this.printer.end('');
        this.onSources(compiler);
    }
    onCompileEnd(compiler) {
        if (compiler.output.errors) {
            this.onErrors(compiler);
        }
    }
    onSaveStart(compiler) {
        if (!compiler.output.errors) {
            this.onContracts(compiler);
        }
    }
    onSaveEnd(compiler) {
        this.onOverview(compiler);
        this.printer.end('');
    }
    onSources(compiler) {
        const sources = Object.keys(compiler.input.sources || {});
        if (sources.length) {
            this.printer.end(this.printer.indent(1, ''), 'Sources');
            sources.forEach((source) => {
                this.printer.end(this.printer.indent(2, ''), this.printer.colorize('gray', source));
            });
        }
    }
    onErrors(compiler) {
        const errors = compiler.output.errors;
        if (errors && errors.length) {
            this.printer.end(this.printer.indent(1, ''), 'Errors');
            errors.filter((e) => e.formattedMessage).forEach((error) => {
                const color = this.getErrorColor(error);
                this.printer.end(this.printer.indent(2, ''), this.printer.colorize(color, error.formattedMessage.trim()));
            });
        }
    }
    onContracts(compiler) {
        const contracts = Object.keys(compiler.output.contracts || {});
        if (contracts.length) {
            this.printer.end(this.printer.indent(1, ''), 'Contracts');
            contracts.forEach((contract) => {
                this.printer.end(this.printer.indent(2, ''), this.printer.colorize('gray', `${contract}: ${Object.keys(compiler.output.contracts[contract]).join(', ')}`));
            });
        }
    }
    onOverview(compiler) {
        this.printer.end();
        const messages = [];
        const sources = Object.keys(compiler.input.sources || {}).length;
        const contracts = Object.keys(compiler.output.contracts || {}).length;
        const errors = Object.keys(compiler.output.errors || {}).length;
        if (contracts) {
            messages.push(this.printer.indent(1, ''), this.printer.colorize('greenBright', contracts), ' contracts');
        }
        if (sources) {
            messages.push(this.printer.indent(1, ''), this.printer.colorize('gray', sources), ' sources');
        }
        if (errors) {
            messages.push(this.printer.indent(1, ''), this.printer.colorize('redBright', errors), ' errors');
        }
        if (messages.length) {
            this.printer.end(...messages);
        }
    }
    getErrorColor(error) {
        if (error.severity === 'error') {
            return 'redBright';
        }
        else {
            return 'yellowBright';
        }
    }
}
exports.DefaultReporter = DefaultReporter;
//# sourceMappingURL=reporter.js.map